#include "Deductions.h"

namespace opensmt {

//static SolverId SolverId_Undef = {UINT32_MAX};
uint32_t SolverDescr::id_counter = 0;

}
